Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1620)

Unified Diff: chrome/browser/profiles/profile.cc

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/profiles/profile.h ('k') | chrome/browser/profiles/profile_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile.cc
diff --git a/chrome/browser/profiles/profile.cc b/chrome/browser/profiles/profile.cc
index fffeb89a39a02871189baddcbe2f8f3fa9d6091c..eea0472ff86fc94f22e231f703ddda6baff66b04 100644
--- a/chrome/browser/profiles/profile.cc
+++ b/chrome/browser/profiles/profile.cc
@@ -96,10 +96,10 @@ void Profile::RegisterUserPrefs(PrefService* prefs) {
prefs->RegisterBooleanPref(prefs::kSafeBrowsingReportingEnabled,
false,
PrefService::UNSYNCABLE_PREF);
// TODO(erg): kSpeechInputFilterProfanities should also be moved to
// speech_input_extension_manager.cc, but is more involved because of
// BrowserContext/Profile confusion because of ChromeSpeechInputPreferences.
- prefs->RegisterBooleanPref(prefs::kSpeechInputFilterProfanities,
+ prefs->RegisterBooleanPref(prefs::kSpeechRecognitionFilterProfanities,
true,
PrefService::UNSYNCABLE_PREF);
prefs->RegisterBooleanPref(prefs::kDisableExtensions,
@@ -96,10 +96,10 @@ void Profile::RegisterUserPrefs(PrefService* prefs) {
false,
PrefService::UNSYNCABLE_PREF);
- // TODO(erg): kSpeechInputFilterProfanities should also be moved to
+ // TODO(erg): kSpeechRecognitionFilterProfanities should also be moved to
// speech_input_extension_manager.cc, but is more involved because of
// BrowserContext/Profile confusion because of ChromeSpeechInputPreferences.
« no previous file with comments | « chrome/browser/profiles/profile.h ('k') | chrome/browser/profiles/profile_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698